//
//Copyright 2002-2011 Aspose Pty Ltd. All Rights Reserved.
//
//This file is part of Aspose.Pdf for Java. The source code in this file
//is only intended as a supplement to the documentation, and is provided
//"as is", without warranty of any kind, either expressed or implied.
//

//==========================================================================================================//
//=============== This demo explains the steps to create Header/Footer in PDF document =====================//
//==========================================================================================================//

package samples.demos.header;
import java.io.FileInputStream;
import aspose.pdf.*;

/**
 * This example domestrates how to use pdf header and footer.
 */
public class HeaderAndFooterExample {
    public static void main(String args[]){

		//if you got a license, uncomment following lines
		/*
		// create a license object
		aspose.pdf.License pdf_lic = new aspose.pdf.License();
       	try {
		// specify the path for license file
			pdf_lic.setLicense(new FileInputStream(("D:/Aspose.Total.Product.Family.lic")));
       	} catch (Exception e) {
       		System.out.println(e.getMessage());
       	}*/
        
        try{
			//Instantiate a Pdf object by calling its empty constructor
			Pdf pdf = new Pdf();
			//add a section
			Section sec1 = pdf.getSections().add();

			//Instantiate First HeaderFooter object and pass the Section reference in which
			//the header or footer is to be added
			HeaderFooter Header1 = new HeaderFooter(sec1);
			//Set the header of odd pages of the PDF document
			sec1.setOddHeader(Header1);
			//Enable this header for first page only
			Header1.setIsFirstPageOnly(true);

			//Instantiate a Text paragraph that will store the content to show as header
			Text text = new Text("Header for first page only");
			// specify the font color information for text object
			text.getTextInfo().setColor(new aspose.pdf.Color("Green"));
			//specify the font name as Arial
			text.getTextInfo().setFontName("Arial");
			// set the top margin informatin for Header as 20
			Header1.getMargin().setTop(20);
			//Add the text object to the Paragraphs collection of HeaderFooter object to
			//display header on the pages of PDF document
			Header1.getParagraphs().add(text);

			//Instantiate Second HeaderFooter object and pass the Section reference in which
			//the header or footer is to be added
			HeaderFooter Header2 = new HeaderFooter(sec1);
			//Set the additional header of odd pages of the PDF document
			sec1.setAdditionalOddHeader(Header2);
			//Enable this header for subsequent page only
			Header2.setIsSubsequentPagesOnly(true);
			//Instantiate a Text paragraph that will store the content to show as header
			text = new Text("Odd header for subsequent pages");
			//Add the text object to the Paragraphs collection of HeaderFooter object to
			//display header on the pages of PDF document
			Header2.getParagraphs().add(text);

			//Instantiate Third HeaderFooter object and pass the Section reference in which
			//the header or footer is to be added
			HeaderFooter hf3 = new HeaderFooter(sec1);
			//Set the additional header of even pages of the PDF document
			sec1.setAdditionalEvenHeader(hf3);
			//Enable this header for subsequent page only			 
			hf3.setIsSubsequentPagesOnly(true);
			//Instantiate a Text paragraph that will store the content to show as header
			text = new Text(hf3, "Even header for subsequent pages");
			//Add the text object to the Paragraphs collection of HeaderFooter object to
			//display header on the pages of PDF document
			hf3.getParagraphs().add(text);

			// Create a loop to create 6 pages and add sample text over idividual pages
			for (int i = 1; i <= 6; i++)
			{
				// Create a text object and add it to section element
				Text text1 = new Text(sec1);
				// set the value that indicates that Text paragraph is first paragraph of a page
				text1.setIsFirstParagraph(true);
				// add text object to paragraphs collection of section element
				sec1.getParagraphs().add(text1);
				// Create a segment object and pass text1 as argument			        
				Segment segment1 = new Segment(text1);
				// add segment2 to segments collection of text1 element			        
				text1.getSegments().add(segment1);
				// assign some contents to segment object			        
				segment1.setContent("Sample Text Paragraph on page " + Integer.toString(i));
				// set the Font Size as 14
				segment1.getTextInfo().setFontSize(14);
				// Specify the font color information as Maroon
				segment1.getTextInfo().setColor(new aspose.pdf.Color("Maroon"));
				// set the font name for text object
				segment1.getTextInfo().setFontName("Helvetica-BoldOblique");
			}

			//Create a new HeaderFooter object to be added as Footer in document
			HeaderFooter footer = new HeaderFooter(sec1);
			// specify the Alignment information for the contents of HeaderFooter as Center Aligned 
			footer.getTextInfo().setAlignment(AlignmentType.Center);
			// set the font color information for HeaderFooter object as Red
			footer.getTextInfo().setColor(new aspose.pdf.Color("Red"));
			// create a sample text object with special replaceabel symbols
			Text footText = new Text(footer, "Page: $p / $P");
			// add text object to paragraphs collection of HeaderFooter object
			footer.getParagraphs().add(footText);
			// set above create HeaderFooter object as Odd Footer for section1
			sec1.setOddFooter(footer);
			// set above create HeaderFooter object as Even Footer for section1
			sec1.setEvenFooter(footer);


			//Save the resultant PDF
			pdf.save("D:\\pdftest\\Resultant.pdf");

		}catch (Exception excep)
		{
			System.out.println(excep.getMessage());
		}
    }
}
