//
//Copyright 2002-2011 Aspose Pty Ltd. All Rights Reserved.
//
//This file is part of Aspose.Pdf for Java. The source code in this file
//is only intended as a supplement to the documentation, and is provided
//"as is", without warranty of any kind, either expressed or implied.
//

//==========================================================================================================//
//============= This demo explains the steps to create List Of Tables inside PDF document ==================//
//==========================================================================================================//

package samples.demos.listoftables;

import java.io.File;
import java.io.InputStream;
import aspose.pdf.*;

/**
 * This example domestrates how to use pdf dom.
 */
public class ListOfTables{
    public static void main(String args[]){

    	//if you got a license, uncomment following lines
		/*
		// create a license object
		aspose.pdf.License pdf_lic = new aspose.pdf.License();
       	try {
		// specify the path for license file
			pdf_lic.setLicense(new FileInputStream(("D:/Aspose.Total.Product.Family.lic")));
       	} catch (Exception e) {
       		System.out.println(e.getMessage());
       	}*/

		try
		{
			//Instantiate Pdf instance by calling its empty constructor
			Pdf pdf = new Pdf();
			//Create a list section
			ListSection tocsec = new ListSection("List of Tables");
			//Add the list section to the sections collection of the Pdf document
			pdf.getSections().add(tocsec);

			// Get the Text value of the title of ListSection.
			Text text = tocsec.getTitle();
			// set the font name for TOC title
			text.getSegments().getSegment(0).getTextInfo().setFontName("Helvetica");
			// set the font size information for TOC title
			text.getSegments().getSegment(0).getTextInfo().setFontSize(16);
			// set the Bottom margin information for TOC title
			text.getMargin().setBottom(20);
			//Set the length of list levels to 4  
			tocsec.getListFormatArray().setLength(4);
			// Set left margin information for first level list item 
			tocsec.getListFormatArray().getListLevelFormat(0).setLeftMargin(0);
			// Set Font Name information for first level list item 
			tocsec.getListFormatArray().getListLevelFormat(0).getTextInfo().setFontName("Helvetica");
			// Set Font Size information for first level list item 
			tocsec.getListFormatArray().getListLevelFormat(0).getTextInfo().setFontSize(24);

			//Set its list type as table of of contents
			tocsec.setListType(ListType.ListOfTables);
			// Create a section in the Pdf document
			Section sec = pdf.getSections().add();

			// create a table object 
			Table table1 = new Table();
			// add table ot paragraphs collection of PDF section 
			sec.getParagraphs().add(table1);
			// set the column width information for table
			table1.setColumnWidths("70 2cm");
			// set the title for table object
			table1.setTitle("Table List 1");

			// Create a row and add it to rows collection of table 
			Row row1 = table1.getRows().add();
			// create a cell and add it to cells collection of row1
			Cell cellRow1 = row1.getCells().add("ColumnsSpan = 2");
			// set the columnspan information for cell1 object
			cellRow1.setColumnsSpan(2);
			// set the border information for cell object
			cellRow1.setBorder(new BorderInfo(BorderSide.All.getValue(), 0.5f));

			// create a second row and add it to rows collection of table
			Row row2 = table1.getRows().add();
			// create a cell object and add it to second row of table
			Cell cell1Row2 = row2.getCells().add("cell1");
			// set border information for table cell on second row
			cell1Row2.setBorder(new BorderInfo(BorderSide.All.getValue(), 0.5f));

			// create a cell object and add it to cells collection of second row
			Cell cell2Row2 = row2.getCells().add("cell2");
			// set the border information for second cell of second row
			cell2Row2.setBorder(new BorderInfo(BorderSide.All.getValue(), 0.5f, new aspose.pdf.Color("Red")));
			// add the table to be listed in list section
			table1.setIsInList(true);

			//Save the resultant PDF
			pdf.save("D:\\pdftest\\Resultant.pdf");
		}
		catch (Exception excep)
		{
			System.out.println(excep.getMessage());
		}
	}
}
