//
//Copyright 2002-2011 Aspose Pty Ltd. All Rights Reserved.
//
//This file is part of Aspose.Pdf for Java. The source code in this file
//is only intended as a supplement to the documentation, and is provided
//"as is", without warranty of any kind, either expressed or implied.
//

//==========================================================================================================//
//=============== This demo explains the steps to create Nested Tables in PDF document =====================//
//======= The Nested table will be added in Right cell of main table with Yellow BackGround color ==========//
//==========================================================================================================//

package samples.demos.nestedtable;

import java.io.File;
import java.io.FileInputStream;
import aspose.pdf.*;

/**
 * This example domestrates how to use table in pdf.
 */
public class NestedTableExample {
    public static void main(String args[]){

		//if you got a license, uncomment following lines
		/*
		// create a license object
		aspose.pdf.License pdf_lic = new aspose.pdf.License();
       	try {
		// specify the path for license file
			pdf_lic.setLicense(new FileInputStream(("D:/Aspose.Total.Product.Family.lic")));
       	} catch (Exception e) {
       		System.out.println(e.getMessage());
       	}*/
            
    	try{

			//Instantiate Pdf instance by calling its empty constructor
			Pdf pdf = new Pdf();
			//create a Section object and add it to PDF document
			Section sec1 = pdf.getSections().add();

			// create a sample text object as heading for PDF document
			Text text = new Text(sec1, "This Demo shows how to create Nested Table!\n");
			// specify that heading should be Bold
			text.getTextInfo().setIsTrueTypeFontBold(true);
			// set the font face information as Arial
			text.getTextInfo().setFontName("Arial");
			// set the font size for text object
			text.getTextInfo().setFontSize(14);
			// specify font color information as Green
			text.getTextInfo().setColor(new aspose.pdf.Color("Green"));
			// add the text object to paragraphs collection of section
			sec1.getParagraphs().add(text);

			// create a main table object
			Table table = new Table(sec1);
			// specify the column width information for main table 
			table.setColumnWidths("150 150");
			// set the border style information for main table
			table.setDefaultCellBorder(new BorderInfo(BorderSide.All.getValue(), 0.8F, new aspose.pdf.Color("Orange")));

			// create row object and add it to main table
			Row row1 = table.getRows().add();
			// create a cell object and add it to 1st row of main table
			row1.getCells().add("Left Cell");
			// specify the BackGround color information for left cell of Row1
			row1.getCells().getCell(0).setBackgroundColor(new aspose.pdf.Color("Silver"));
			// specify the Horizontal Alignment information for left cell of Row1
			row1.getCells().getCell(0).setAlignment(AlignmentType.Center);
			// specify the Vertical Alignment information for left cell of Row1
			row1.getCells().getCell(0).setVerticalAlignment(VerticalAlignmentType.Center);
			// specify the Text Color information for left cell of Row1
			row1.getCells().getCell(0).getDefaultCellTextInfo().setColor(new aspose.pdf.Color("Maroon"));
			// specify Fix Row height information for Row1
			row1.setFixedRowHeight(35);

			// create a cell object and add it to Row1 of main table
			Cell cell2 = row1.getCells().add();
			// specify the Top margin information for second cell of Row1
			cell2.getDefaultPadding().setTop(3);
			// specify the Bottom margin information for second cell of Row1
			cell2.getDefaultPadding().setBottom(3);
			// specify the Left margin information for second cell of Row1
			cell2.getDefaultPadding().setLeft(3);
			// specify the Right margin information for second cell of Row1
			cell2.getDefaultPadding().setRight(3);

			// ======= In following code we will create Nested Table =======//
			// create a new Table which will be added as Nested Table in main Table
			Table nestedTable = new Table(sec1);
			// specify the Column width information for NestedTable object
			nestedTable.setColumnWidths("70 70");
			// specify the Border information for Nested Table
			nestedTable.setDefaultCellBorder(new BorderInfo(BorderSide.All.getValue(), 0.9F, new aspose.pdf.Color("Blue")));
			// Set the BackGround color information for Nested Tabel as Yellow
			nestedTable.setBackgroundColor(new aspose.pdf.Color("Yellow"));
			// add the newly create NestedTable to paragraphs collection of cell2 or Row1
			cell2.getParagraphs().add(nestedTable);

			// create first row object for NestedTable
			Row row21 = nestedTable.getRows().add();
			// specify the Fix Row Height information for first row object of Nested Table
			row21.setFixedRowHeight(15);
			// add a cell to first row of Nested Table
			row21.getCells().add("Col (1,1)");
			// add second cell to first row of Nested Table
			row21.getCells().add("Col (1,2)");
			// add a new row to NestedTable
			Row row22 = nestedTable.getRows().add();
			// specify the row Height information for second row of Nested Table
			row22.setFixedRowHeight(15);
			// add fist cell to second row of Nested Table
			row22.getCells().add("Col (2,1)");
			// add second cell to second row of Nested Table
			row22.getCells().add("Col (2,2)");

			// add main table to paragraphs collection of section object   
			sec1.getParagraphs().add(table);

			//Save the resultant PDF
			pdf.save("D:\\pdftest\\Resultant.pdf");
		
		}catch (Exception excep)
		{
			System.out.println(excep.getMessage());
		}
    }
}

